RAG Pipeline
============

Vector store, embedding providers, and graph-expanded semantic search.

.. automodule:: rag
   :members:
   :show-inheritance:

.. automodule:: rag.vector_store
   :members:
   :show-inheritance:

.. automodule:: rag.embedding_provider
   :members:
   :show-inheritance:

.. automodule:: rag.search
   :members:
   :show-inheritance:
